==> 3.5.12-core.tar: kdevelop/languages/cpp/qtdesignercppintegration.h <==
/***************************************************************************
*   Copyright (C) 2004 by Alexander Dymo                                  *
*   adymo@mksat.net                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
***************************************************************************/
#ifndef QTDESIGNERCPPINTEGRATION_H
#define QTDESIGNERCPPINTEGRATION_H

#include <qtdesignerintegration.h>

class QtDesignerCppIntegration : public QtDesignerIntegration
{
	Q_OBJECT
public:
	QtDesignerCppIntegration( KDevLanguageSupport *part, ImplementationWidget *impl );

protected:
	virtual void addFunctionToClass( KInterfaceDesigner::Function function, ClassDom klass );
	TQString accessID( FunctionDom fun ) const;

	virtual void processImplementationName( TQString &name );
};

#endif 
// kate: indent-mode csands; tab-width 4;

==> 3.5.13-core.tar: kdevelop/languages/cpp/qtdesignercppintegration.h <==
/***************************************************************************
*   Copyright (C) 2004 by Alexander Dymo                                  *
*   adymo@mksat.net                                                       *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
***************************************************************************/
#ifndef TQTDESIGNERCPPINTEGRATION_H
#define TQTDESIGNERCPPINTEGRATION_H

#include <qtdesignerintegration.h>

class QtDesignerCppIntegration : public QtDesignerIntegration
{
	Q_OBJECT
  TQ_OBJECT
public:
	QtDesignerCppIntegration( KDevLanguageSupport *part, ImplementationWidget *impl );

protected:
	virtual void addFunctionToClass( KInterfaceDesigner::Function function, ClassDom klass );
	TQString accessID( FunctionDom fun ) const;

	virtual void processImplementationName( TQString &name );
};

#endif 
// kate: indent-mode csands; tab-width 4;
